;*****************************************************************************
;				NICST TOOL
;
;  FP-13 Static SMWIR Xtalk test. Calculate XF_dn, XF_L, CNR, and PVP using the sum
;  of the dn in the sender band as the sender detector dn.
;  
;  v1.0 - 1/23/2008 - Jeff McIntire
;*****************************************************************************

PRO fp_13_SMWIR_sender

n_bands=8

bandname=['I3','I4','M10','M11','M12','M13','M8','M9']

uaidname=['3102097','3102104','3102107','3102118','3102124','3102150','3102163','3102164','3102165','3102168','3102193']
n_uaid=N_ELEMENTS(uaidname)
colnum=[33,36,69,33,39,66,8,28,57,49,33]

;*****************************************************************************
;  Create output files.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN

	outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.snd_avg_coeff.dat'
	openw,lun,outfname1,/get_lun

;*****************************************************************************
;  Input DN to files for I and M bands.
;*****************************************************************************

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.dn.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

;*****************************************************************************
;  Calculate crosstalk parameters and write to an output file.
;*****************************************************************************

	fmt='(i3, 5x, a5, 5x, i2, 5x, i2, 5x, a5, 5x, i2, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d)'

	L_max_hg=3.47
	L_max_lg=404.891
	L_typ_hg=0.79
	L_typ_lg=9.53
	L_max=[72.5,3.014,71.2,31.80,2.827,L_max_hg,164.9,77.1]
	L_typ=[7.3,0.11,7.3,0.12,0.1,L_typ_hg,5.4,6]

	n_subset=2
	band_skip=fltarr(colnum[uaid])
	XF_dn=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	XF_L=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	CNR=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP_1=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)
	PVP_2=fltarr(colnum[uaid],32,n_subset,n_bands,32,n_subset)

	openw,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.snd_avg_coeff.dat',/get_lun
	printf,lun,'Collect  S_Band  S_Detector  S_Subset  R_Band  R_Detector  R_Subset   XF_dn   XF_L   CNR   PVP'

	FOR col=0, colnum[uaid]-1 DO BEGIN
		band_skip[col]=0

		; U3102097
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 24 OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 THEN band_skip[col]=1
		ENDIF
		; U3102104
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 21 OR col EQ 25 $
				OR col EQ 27 OR col EQ 29 OR col EQ 31 OR col EQ 33 OR col EQ 35 THEN band_skip[col]=1
		ENDIF
		; U3102107
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 6 OR col EQ 8 OR col EQ 10 OR col EQ 12 $
				OR col EQ 14 OR col EQ 16 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 OR col EQ 34 $
				OR col EQ 36 OR col EQ 38 OR col EQ 40 OR col EQ 42 OR col EQ 45 $
				OR col EQ 47 OR col EQ 49 OR col EQ 51 OR col EQ 53 OR col EQ 55 $
				OR col EQ 57 OR col EQ 59 OR col EQ 61 OR col EQ 63 OR col EQ 66 $
				OR col EQ 68 THEN band_skip[col]=1
		ENDIF
		; U3102118
		IF uaid EQ 3 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 6 OR col EQ 8 OR col EQ 10 OR col EQ 12 $
				OR col EQ 14 OR col EQ 16 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 24 OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 THEN band_skip[col]=1
		ENDIF
		; U3102124
		IF uaid EQ 4 THEN BEGIN
			IF col EQ 4 OR col EQ 6 OR col EQ 10 OR col EQ 12 OR col EQ 14 OR col EQ 17 $
				OR col EQ 19 OR col EQ 21 OR col EQ 23 OR col EQ 25 OR col EQ 28 $
				OR col EQ 30 OR col EQ 32 OR col EQ 34 OR col EQ 36 OR col EQ 38 THEN band_skip[col]=1
		ENDIF
		; U3102150
		IF uaid EQ 5 THEN BEGIN
			IF col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 8 OR col EQ 10 OR col EQ 12 $
				OR col EQ 14 OR col EQ 16 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 24 OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 $
				OR col EQ 34 OR col EQ 36 OR col EQ 38 OR col EQ 40 OR col EQ 42 $
				OR col EQ 44 OR col EQ 46 OR col EQ 48 OR col EQ 50 OR col EQ 52 $
				OR col EQ 55 OR col EQ 57 OR col EQ 59 OR col EQ 61 OR col EQ 63 $
				OR col EQ 65  THEN band_skip[col]=1
		ENDIF
		; U3102163
		IF uaid EQ 6 THEN BEGIN
			IF col EQ 3 OR col EQ 7 THEN band_skip[col]=1
		ENDIF
		; U3102164
		IF uaid EQ 7 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 THEN band_skip[col]=1
		ENDIF
		; U3102165
		IF uaid EQ 8 THEN BEGIN
			IF col EQ 1 OR col EQ 4 OR col EQ 7 OR col EQ 10 OR col EQ 13 OR col EQ 17 $
				OR col EQ 20 OR col EQ 23 OR col EQ 29 OR col EQ 32 OR col EQ 35 $
				OR col EQ 38 OR col EQ 41 OR col EQ 44 OR col EQ 52 OR col EQ 55 THEN band_skip[col]=1
		ENDIF
		; U3102168
		IF uaid EQ 9 THEN BEGIN
			IF col EQ 1 OR col EQ 5 OR col EQ 8 OR col EQ 11 OR col EQ 14 OR col EQ 17 $
				OR col EQ 20 OR col EQ 23 OR col EQ 26 OR col EQ 29 OR col EQ 32 $
				OR col EQ 35 OR col EQ 38 OR col EQ 41 OR col EQ 44 OR col EQ 47 THEN band_skip[col]=1
		ENDIF
		; U3102193
		IF uaid EQ 10 THEN BEGIN
			IF col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 8 OR col EQ 10 OR col EQ 12 $
				OR col EQ 14 OR col EQ 16 OR col EQ 18 OR col EQ 20 OR col EQ 22 $
				OR col EQ 24 OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 THEN band_skip[col]=1
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		; Sender band (s_band), detector (s_det), and subset (isubset).
		s_band=high_det[col,0]
		s_det=fix(high_det[col,1])

		s_gain=1
		; L_max of sender detector (for dual gain bands).
		IF uaid EQ 8 OR uaid EQ 9 THEN BEGIN
			L_max[5]=L_max_hg
			IF band_info[col,s_band,2] NE 1 THEN L_max[5]=L_max_lg

			IF band_info[col,s_band,2] NE 1 THEN s_gain=0
			IF band_info[col,s_band,2] EQ 1 THEN s_gain=1
		ENDIF

		IF s_band LE 1 THEN n_subset=2
		IF s_band GT 1 THEN n_subset=1
		FOR isubset=0, n_subset-1 DO BEGIN

			; Receiver band (ib), detector (id), and subset (is).
			FOR ib=0, 7 DO BEGIN
				IF ib EQ 4 OR ib EQ 5 THEN BEGIN
					IF band_skip[col] EQ 1 THEN goto,skip_band_r
				ENDIF

				IF ib LE 1 THEN n_d=32
				IF ib GT 1 THEN n_d=16
				FOR id=0, n_d-1 DO BEGIN

					ig=1
					IF uaid EQ 8 OR uaid EQ 9 THEN BEGIN
						IF band_info[col,ib,2] EQ 0 THEN BEGIN
							IF det_low_gain[col,ib,id] EQ 1 THEN ig=0
							IF det_low_gain[col,ib,id] EQ 0 THEN ig=1
						ENDIF
						IF band_info[col,ib,2] EQ 1 THEN ig=1
						IF band_info[col,ib,2] EQ 2 THEN ig=0
					ENDIF

					IF ib LE 1 THEN n_subset=2
					IF ib GT 1 THEN n_subset=1
					FOR is=0, n_subset-1 DO BEGIN
						dn_snd_band=total(dn[col,s_band,*,isubset])

						IF dn[col,s_band,s_det,isubset] EQ 0 THEN BEGIN
							dn[col,s_band,s_det,isubset]=1000000.0
						ENDIF
						XF_dn[col,s_det,isubset,ib,id,is]= $
							dn[col,ib,id,is]/dn_snd_band
						XF_L[col,s_det,isubset,ib,id,is]= $
							gain[s_band,s_det,s_gain,isubset]*dn[col,ib,id,is]/ $
							(gain[ib,id,ig,is]*dn_snd_band)
						PVP_1[col,s_det,isubset,ib,id,is]= $
							2*sqrt(3)*L_max[s_band]*dn[col,ib,id,is]* $
							gain[s_band,s_det,s_gain,isubset]/(dn_snd_band*std[col,ib,id,is])
						PVP_2[col,s_det,isubset,ib,id,is]= $
							L_max[s_band]*dn[col,ib,id,is]*gain[s_band,s_det,s_gain,isubset]/ $
							(dn_snd_band*gain[ib,id,ig,is]*0.002*L_typ[ib])
						IF ib EQ 5 THEN BEGIN
							PVP_1[col,s_det,isubset,ib,id,is]= $
								2*L_max[s_band]*dn[col,ib,id,is]* $
								gain[s_band,s_det,s_gain,isubset]/(dn_snd_band*std[col,ib,id,is])
						ENDIF
						IF abs(PVP_2[col,s_det,isubset,ib,id,is]) GT $
							abs(PVP_1[col,s_det,isubset,ib,id,is]) THEN BEGIN
							PVP[col,s_det,isubset,ib,id,is]=PVP_1[col,s_det,isubset,ib,id,is]
						ENDIF ELSE BEGIN
							PVP[col,s_det,isubset,ib,id,is]=PVP_2[col,s_det,isubset,ib,id,is]
						ENDELSE
						CNR[col,s_det,isubset,ib,id,is]=PVP_1[col,s_det,isubset,ib,id,is]/4
						printf,lun,format=fmt,col+1,bandname[s_band], $
							s_det+1,isubset,bandname[ib],id+1,is, $
							XF_dn[col,s_det,isubset,ib,id,is], $
							XF_L[col,s_det,isubset,ib,id,is], $
							CNR[col,s_det,isubset,ib,id,is], $
							PVP[col,s_det,isubset,ib,id,is]
					ENDFOR
				ENDFOR
				skip_band_r:
			ENDFOR
		ENDFOR
		skip_col:

		save,/compress,gain,XF_dn,XF_L,CNR,PVP,filename='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+ $
			uaidname[uaid]+'.snd_avg_coeff.sav'
	ENDFOR
	close,lun,/file,/all
	free_lun,lun

	skip:
ENDFOR

END
