;*****************************************************************************
;				NICST TOOL
;
;  Band average the FP-13 LWIR crosstalk coefficients.
;  
;  v1.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO SMWIR_det_avg

close,/all

ndet_I=32
ndet_M=16

uaidname=['3102097','3102104','3102107','3102118','3102124','3102150','3102163','3102164','3102165','3102168','3102193']
n_uaid=N_ELEMENTS(uaidname)
colnum=[33,36,69,33,39,66,8,28,57,49,33]

fmt='(d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13, 5x, d13)'
header='M13  M12  I4_SS1  I4_SS2  I3_SS1  I3_SS2  M10  M11  M8  M9'

;*****************************************************************************
;  Read in data and create output files.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	IF uaid NE 8 AND uaid NE 9 THEN BEGIN
		outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.dn.dat'
		outfname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.L.dat'
		outfname3='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.CNR.dat'
		outfname4='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.PVP.dat'
		openw,lun,outfname1,/get_lun
		openw,lon,outfname2,/get_lun
		openw,len,outfname3,/get_lun
		openw,lin,outfname4,/get_lun
		printf,lun,header
		printf,lon,header
		printf,len,header
		printf,lin,header
	ENDIF
	IF uaid EQ 8 OR uaid EQ 9 THEN BEGIN
		outfname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.alg.dn.dat'
		outfname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.flg.dn.dat'
		outfname3='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.alg.L.dat'
		outfname4='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.flg.L.dat'
		outfname5='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.alg.CNR.dat'
		outfname6='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.flg.CNR.dat'
		outfname7='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.alg.PVP.dat'
		outfname8='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.det_avg.flg.PVP.dat'
		openw,lun,outfname1,/get_lun
		openw,lon,outfname3,/get_lun
		openw,len,outfname5,/get_lun
		openw,lin,outfname7,/get_lun
		openw,lun_2,outfname2,/get_lun
		openw,lon_2,outfname4,/get_lun
		openw,len_2,outfname6,/get_lun
		openw,lin_2,outfname8,/get_lun
		printf,lun,header
		printf,lon,header
		printf,len,header
		printf,lin,header
		printf,lun_2,header
		printf,lon_2,header
		printf,len_2,header
		printf,lin_2,header
	ENDIF

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.dn.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.coeff.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	; reformed data
	XF_dn_I_det_avg=fltarr(ndet_I,2,2,2)
	XF_L_I_det_avg=fltarr(ndet_I,2,2,2)
	CNR_I_det_avg=fltarr(ndet_I,2,2,2)
	PVP_I_det_avg=fltarr(ndet_I,2,2,2)
	XF_dn_M_det_avg=fltarr(ndet_I,2,6)
	XF_L_M_det_avg=fltarr(ndet_I,2,6)
	CNR_M_det_avg=fltarr(ndet_I,2,6)
	PVP_M_det_avg=fltarr(ndet_I,2,6)

	; reformed data for dual gain bands
	XF_dn_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	XF_L_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	CNR_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	PVP_I_det_avg_g=fltarr(ndet_I,2,2,2,2,2)
	XF_dn_M_det_avg_g=fltarr(ndet_I,2,6,2,2)
	XF_L_M_det_avg_g=fltarr(ndet_I,2,6,2,2)
	CNR_M_det_avg_g=fltarr(ndet_I,2,6,2,2)
	PVP_M_det_avg_g=fltarr(ndet_I,2,6,2,2)

;*****************************************************************************
;  Skip bad collects and reform data.
;*****************************************************************************

	count1=0
	count2=0
	FOR col=0, colnum[uaid]-1 DO BEGIN
		flag=0

		; U3102097
		IF uaid EQ 0 THEN BEGIN
			IF col EQ 16 THEN goto,skip_col
		ENDIF

		; U3102104
		IF uaid EQ 1 THEN BEGIN
			IF col EQ 18 OR col EQ 19 OR col EQ 22 OR col EQ 23 THEN goto,skip_col
		ENDIF

		; U3102107
		IF uaid EQ 2 THEN BEGIN
			IF col EQ 4 OR col EQ 23 OR col EQ 24 OR col EQ 41 OR col EQ 64 THEN goto,skip_col
		ENDIF

		; U3102118
		IF uaid EQ 3 THEN BEGIN
			IF col EQ 4 THEN goto,skip_col
		ENDIF

		; U3102124
		IF uaid EQ 4 THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 7 $
				OR col EQ 8 OR col EQ 10 OR col EQ 12 OR col EQ 14 OR col EQ 15 $
				OR col EQ 17 OR col EQ 19 OR col EQ 21 OR col EQ 23 OR col EQ 25 $
				OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 OR col EQ 34 $
				OR col EQ 36 OR col EQ 38 THEN goto,skip_col
		ENDIF

		; U3102150
		IF uaid EQ 5 THEN BEGIN
			IF col EQ 0 OR col EQ 53 THEN goto,skip_col
		ENDIF

		; U3102163
		IF uaid EQ 6 THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 3 OR col EQ 4 OR col EQ 5 OR col EQ 7 $
				THEN goto,skip_col
		ENDIF

		; U3102164
		IF uaid EQ 7 THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 THEN goto,skip_col
		ENDIF

		; U3102165
		IF uaid EQ 8 THEN BEGIN
			IF col EQ 1 OR col EQ 4 OR col EQ 7 OR col EQ 10 OR col EQ 13 OR col EQ 15 $
				OR col EQ 17 OR col EQ 20 OR col EQ 23 OR col EQ 25 OR col EQ 26 $
				OR col EQ 27 OR col EQ 29 OR col EQ 32 OR col EQ 35 OR col EQ 38 $
				OR col EQ 41 OR col EQ 44 OR col EQ 46 OR col EQ 47 OR col EQ 48 $
				OR col EQ 49 OR col EQ 50 OR col EQ 52 OR col EQ 55 THEN goto,skip_col
		ENDIF
		; U3102165 auto low collects
		IF uaid EQ 8 THEN BEGIN
			IF col EQ 0 OR col EQ 3 OR col EQ 6 OR col EQ 9 OR col EQ 12 OR col EQ 16 $
				OR col EQ 19 OR col EQ 22 OR col EQ 28 OR col EQ 31 OR col EQ 34 $
				OR col EQ 37 OR col EQ 40 OR col EQ 43 OR col EQ 51 OR col EQ 54 THEN flag=2
		ENDIF
		; U3102165 fixed low collects
		IF uaid EQ 8 THEN BEGIN
			IF col EQ 2 OR col EQ 5 OR col EQ 8 OR col EQ 11 OR col EQ 14 OR col EQ 18 $
				OR col EQ 21 OR col EQ 24 OR col EQ 30 OR col EQ 33 OR col EQ 36 $
				OR col EQ 39 OR col EQ 42 OR col EQ 45 OR col EQ 53 OR col EQ 56 THEN flag=1
		ENDIF

		; U3102168
		IF uaid EQ 9 THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 5 OR col EQ 8 OR col EQ 11 OR col EQ 14 $
				OR col EQ 17 OR col EQ 20 OR col EQ 23 OR col EQ 26 OR col EQ 29 $
				OR col EQ 32 OR col EQ 35 OR col EQ 38 OR col EQ 41 OR col EQ 44 $
				OR col EQ 47 THEN goto,skip_col
		ENDIF
		; U3102168 auto low collects
		IF uaid EQ 9 THEN BEGIN
			IF col EQ 3 OR col EQ 4 OR col EQ 7 OR col EQ 10 OR col EQ 13 OR col EQ 16 $
				OR col EQ 19 OR col EQ 22 OR col EQ 25 OR col EQ 28 OR col EQ 31 $
				OR col EQ 34 OR col EQ 37 OR col EQ 40 OR col EQ 43 OR col EQ 46 THEN flag=2
		ENDIF
		; U3102168 fixed low collects
		IF uaid EQ 9 THEN BEGIN
			IF col EQ 2 OR col EQ 6 OR col EQ 9 OR col EQ 12 OR col EQ 15 OR col EQ 18 $
				OR col EQ 21 OR col EQ 24 OR col EQ 27 OR col EQ 30 OR col EQ 33 $
				OR col EQ 36 OR col EQ 39 OR col EQ 42 OR col EQ 45 OR col EQ 48 THEN flag=1
		ENDIF

		; U3102193
		IF uaid EQ 10 THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		band_lit=fix(high_det[col,0])
		det_lit=fix(high_det[col,1])

		XF_dn_I=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,2,ndet_I,2)
		PVP_I=fltarr(ndet_I,2,2,ndet_I,2)
		FOR j=0, 1 DO BEGIN
			FOR i=0, ndet_I-1, 2 DO BEGIN
				XF_dn_I[*,*,j,i,0]=XF_dn[col,*,*,j,i,0]
				XF_dn_I[*,*,j,i+1,0]=XF_dn[col,*,*,j,i+1,1]
				XF_dn_I[*,*,j,i,1]=XF_dn[col,*,*,j,i,1]
				XF_dn_I[*,*,j,i+1,1]=XF_dn[col,*,*,j,i+1,0]

				XF_L_I[*,*,j,i,0]=XF_L[col,*,*,j,i,0]
				XF_L_I[*,*,j,i+1,0]=XF_L[col,*,*,j,i+1,1]
				XF_L_I[*,*,j,i,1]=XF_L[col,*,*,j,i,1]
				XF_L_I[*,*,j,i+1,1]=XF_L[col,*,*,j,i+1,0]

				CNR_I[*,*,j,i,0]=CNR[col,*,*,j,i,0]
				CNR_I[*,*,j,i+1,0]=CNR[col,*,*,j,i+1,1]
				CNR_I[*,*,j,i,1]=CNR[col,*,*,j,i,1]
				CNR_I[*,*,j,i+1,1]=CNR[col,*,*,j,i+1,0]

				PVP_I[*,*,j,i,0]=PVP[col,*,*,j,i,0]
				PVP_I[*,*,j,i+1,0]=PVP[col,*,*,j,i+1,1]
				PVP_I[*,*,j,i,1]=PVP[col,*,*,j,i,1]
				PVP_I[*,*,j,i+1,1]=PVP[col,*,*,j,i+1,0]
			ENDFOR
		ENDFOR

		XF_dn_M=(reform(XF_dn[col,*,*,2:7,0:15,0]))
		XF_L_M=(reform(XF_L[col,*,*,2:7,0:15,0]))
		CNR_M=(reform(CNR[col,*,*,2:7,0:15,0]))
		PVP_M=(reform(PVP[col,*,*,2:7,0:15,0]))

		IF band_lit LE 1 THEN n_det=32
		IF band_lit LE 1 THEN n_s=2
		IF band_lit GE 2 THEN n_det=16
		IF band_lit GE 2 THEN n_s=1

;*****************************************************************************
;  Make subsample 1 for the I bands higher.
;*****************************************************************************

		XF_dn_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		PVP_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR ib=0, 1 DO BEGIN
					IF mean(XF_L_I[det_lit,s_s,ib,*,0]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,1]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,1]
							PVP_I_t[det_lit,s_s,ib,id,0]=PVP_I[det_lit,s_s,ib,id,0]
							PVP_I_t[det_lit,s_s,ib,id,1]=PVP_I[det_lit,s_s,ib,id,1]
						ENDFOR
					ENDIF
					IF mean(XF_L_I[det_lit,s_s,ib,*,1]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,0]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,0]
							PVP_I_t[det_lit,s_s,ib,id,0]=PVP_I[det_lit,s_s,ib,id,1]
							PVP_I_t[det_lit,s_s,ib,id,1]=PVP_I[det_lit,s_s,ib,id,0]
						ENDFOR
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
		XF_dn_I[*,*,*,*,*]=XF_dn_I_t[*,*,*,*,*]
		XF_L_I[*,*,*,*,*]=XF_L_I_t[*,*,*,*,*]
		CNR_I[*,*,*,*,*]=CNR_I_t[*,*,*,*,*]
		PVP_I[*,*,*,*,*]=PVP_I_t[*,*,*,*,*]

;*****************************************************************************
;  Band average, taking into acount the band substitution tables for each UAID and collect.
;*****************************************************************************

		IF uaid EQ 8 OR uaid EQ 9 THEN goto,uaid_skip
		FOR ib=0, 1 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				FOR r_s=0, 1 DO BEGIN
					XF_dn_I_det_avg[det_lit,s_s,ib,r_s]=XF_dn_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(XF_dn_I[det_lit,s_s,ib,*,r_s])
					XF_L_I_det_avg[det_lit,s_s,ib,r_s]=XF_L_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(XF_L_I[det_lit,s_s,ib,*,r_s])
					CNR_I_det_avg[det_lit,s_s,ib,r_s]=CNR_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(CNR_I[det_lit,s_s,ib,*,r_s])
					PVP_I_det_avg[det_lit,s_s,ib,r_s]=PVP_I_det_avg[det_lit,s_s,ib,r_s] $
						+mean(PVP_I[det_lit,s_s,ib,*,r_s])
				ENDFOR
			ENDFOR
		ENDFOR
		count1=count1+1
		IF count1 EQ 2 THEN BEGIN
			IF uaid NE 4 AND uaid NE 6 AND uaid NE 7 THEN BEGIN
				XF_dn_I_det_avg[det_lit,*,*,*]=XF_dn_I_det_avg[det_lit,*,*,*]/2
				XF_L_I_det_avg[det_lit,*,*,*]=XF_L_I_det_avg[det_lit,*,*,*]/2
				CNR_I_det_avg[det_lit,*,*,*]=CNR_I_det_avg[det_lit,*,*,*]/2
				PVP_I_det_avg[det_lit,*,*,*]=PVP_I_det_avg[det_lit,*,*,*]/2
			ENDIF
			count1=0
		ENDIF
		FOR ib=0, 5 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				XF_dn_M_det_avg[det_lit,s_s,ib]=XF_dn_M_det_avg[det_lit,s_s,ib] $
					+mean(XF_dn_M[det_lit,s_s,ib,*])
				XF_L_M_det_avg[det_lit,s_s,ib]=XF_L_M_det_avg[det_lit,s_s,ib] $
					+mean(XF_L_M[det_lit,s_s,ib,*])
				CNR_M_det_avg[det_lit,s_s,ib]=CNR_M_det_avg[det_lit,s_s,ib] $
					+mean(CNR_M[det_lit,s_s,ib,*])
				PVP_M_det_avg[det_lit,s_s,ib]=PVP_M_det_avg[det_lit,s_s,ib] $
					+mean(PVP_M[det_lit,s_s,ib,*])
			ENDFOR
		ENDFOR
		count2=count2+1
		IF count2 EQ 2 THEN BEGIN
			IF uaid NE 4 AND uaid NE 6 AND uaid NE 7 THEN BEGIN
				XF_dn_M_det_avg[det_lit,*,0:1]=XF_dn_M_det_avg[det_lit,*,0:1]/2
				XF_dn_M_det_avg[det_lit,*,4:5]=XF_dn_M_det_avg[det_lit,*,4:5]/2
				XF_L_M_det_avg[det_lit,*,0:1]=XF_L_M_det_avg[det_lit,*,0:1]/2
				XF_L_M_det_avg[det_lit,*,4:5]=XF_L_M_det_avg[det_lit,*,4:5]/2
				CNR_M_det_avg[det_lit,*,0:1]=CNR_M_det_avg[det_lit,*,0:1]/2
				CNR_M_det_avg[det_lit,*,4:5]=CNR_M_det_avg[det_lit,*,4:5]/2
				PVP_M_det_avg[det_lit,*,0:1]=PVP_M_det_avg[det_lit,*,0:1]/2
				PVP_M_det_avg[det_lit,*,4:5]=PVP_M_det_avg[det_lit,*,4:5]/2
			ENDIF
			count2=0
		ENDIF

		uaid_skip:

		IF uaid EQ 8 OR uaid EQ 9 THEN BEGIN
			FOR ib=0, 1 DO BEGIN
				FOR s_s=0, n_s-1 DO BEGIN
					FOR r_s=0, 1 DO BEGIN
						XF_dn_I_det_avg_g[det_lit,s_s,ib,r_s,1,flag-1]= $
							mean(XF_dn_I[det_lit,s_s,ib,*,r_s])
						XF_L_I_det_avg_g[det_lit,s_s,ib,r_s,1,flag-1]= $
							mean(XF_L_I[det_lit,s_s,ib,*,r_s])
						CNR_I_det_avg_g[det_lit,s_s,ib,r_s,1,flag-1]= $
							mean(CNR_I[det_lit,s_s,ib,*,r_s])
						PVP_I_det_avg_g[det_lit,s_s,ib,r_s,1,flag-1]= $
							mean(PVP_I[det_lit,s_s,ib,*,r_s])
						XF_dn_I_det_avg_g[det_lit,s_s,ib,r_s,0,flag-1]=-999
						XF_L_I_det_avg_g[det_lit,s_s,ib,r_s,0,flag-1]=-999
						CNR_I_det_avg_g[det_lit,s_s,ib,r_s,0,flag-1]=-999
						PVP_I_det_avg_g[det_lit,s_s,ib,r_s,0,flag-1]=-999
					ENDFOR
				ENDFOR
			ENDFOR

			FOR ib=0, 5 DO BEGIN
				FOR s_s=0, n_s-1 DO BEGIN
					IF ib NE 3 THEN BEGIN
						XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=mean(XF_dn_M[det_lit,s_s,ib,*])
						XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=mean(XF_L_M[det_lit,s_s,ib,*])
						CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=mean(CNR_M[det_lit,s_s,ib,*])
						PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=mean(PVP_M[det_lit,s_s,ib,*])
						XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1]=-999
						XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1]=-999
						CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1]=-999
						PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1]=-999
					ENDIF ELSE BEGIN
						IF flag EQ 2 THEN BEGIN
							count3=0
							count4=0
							FOR id=0, ndet_M-1 DO BEGIN
								IF det_low_gain[col,5,id] EQ 1 THEN BEGIN
									XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
										XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1] $
										+XF_dn_M[det_lit,s_s,ib,id]
									XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
										XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1] $
										+XF_L_M[det_lit,s_s,ib,id]
									CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
										CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1] $
										+CNR_M[det_lit,s_s,ib,id]
									PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
										PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1] $
										+PVP_M[det_lit,s_s,ib,id]
									count3=count3+1
								ENDIF ELSE BEGIN
									XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
										XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1] $
										+XF_dn_M[det_lit,s_s,ib,id]
									XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
										XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1] $
										+XF_L_M[det_lit,s_s,ib,id]
									CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
										CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1] $
										+CNR_M[det_lit,s_s,ib,id]
									PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
										PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1] $
										+PVP_M[det_lit,s_s,ib,id]
									count4=count4+1
								ENDELSE
							ENDFOR
								XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
									XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1]/count3
								XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
									XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1]/count3
								CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
									CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1]/count3
								PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
									PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1]/count3
								XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
									XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1]/count4
								XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
									XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1]/count4
								CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
									CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1]/count4
								PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1]= $
									PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1]/count4
						ENDIF
						IF flag EQ 1 THEN BEGIN
							XF_dn_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
								mean(XF_dn_M[det_lit,s_s,ib,*])
							XF_L_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
								mean(XF_L_M[det_lit,s_s,ib,*])
							CNR_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
								mean(CNR_M[det_lit,s_s,ib,*])
							PVP_M_det_avg_g[det_lit,s_s,ib,0,flag-1]= $
								mean(PVP_M[det_lit,s_s,ib,*])
							XF_dn_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=-999
							XF_L_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=-999
							CNR_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=-999
							PVP_M_det_avg_g[det_lit,s_s,ib,1,flag-1]=-999
						ENDIF	
					ENDELSE
				ENDFOR
			ENDFOR
		ENDIF

		skip_col:

	ENDFOR

	IF uaid EQ 2 OR uaid EQ 5 THEN n_s=2
	IF uaid NE 2 AND uaid NE 5 THEN n_s=1
	IF uaid EQ 2 OR uaid EQ 5 THEN n_det=32
	IF uaid NE 2 AND uaid NE 5 THEN n_det=16

;*****************************************************************************
;  Print to file.
;*****************************************************************************

	IF uaid NE 8 AND uaid NE 9 THEN BEGIN
		FOR s_s=0, n_s-1 DO BEGIN
			FOR s_det=0, n_det-1 DO BEGIN
				printf,lun,XF_dn_M_det_avg[s_det,s_s,3],XF_dn_M_det_avg[s_det,s_s,2], $
					XF_dn_I_det_avg[s_det,s_s,1,0],XF_dn_I_det_avg[s_det,s_s,1,1], $
					XF_dn_I_det_avg[s_det,s_s,0,0],XF_dn_I_det_avg[s_det,s_s,0,1], $
					XF_dn_M_det_avg[s_det,s_s,0],XF_dn_M_det_avg[s_det,s_s,1], $
					XF_dn_M_det_avg[s_det,s_s,4],XF_dn_M_det_avg[s_det,s_s,5],format=fmt
				printf,lon,XF_L_M_det_avg[s_det,s_s,3],XF_L_M_det_avg[s_det,s_s,2], $
					XF_L_I_det_avg[s_det,s_s,1,0],XF_L_I_det_avg[s_det,s_s,1,1], $
					XF_L_I_det_avg[s_det,s_s,0,0],XF_L_I_det_avg[s_det,s_s,0,1], $
					XF_L_M_det_avg[s_det,s_s,0],XF_L_M_det_avg[s_det,s_s,1], $
					XF_L_M_det_avg[s_det,s_s,4],XF_L_M_det_avg[s_det,s_s,5],format=fmt
				printf,len,CNR_M_det_avg[s_det,s_s,3],CNR_M_det_avg[s_det,s_s,2], $
					CNR_I_det_avg[s_det,s_s,1,0],CNR_I_det_avg[s_det,s_s,1,1], $
					CNR_I_det_avg[s_det,s_s,0,0],CNR_I_det_avg[s_det,s_s,0,1], $
					CNR_M_det_avg[s_det,s_s,0],CNR_M_det_avg[s_det,s_s,1], $
					CNR_M_det_avg[s_det,s_s,4],CNR_M_det_avg[s_det,s_s,5],format=fmt
				printf,lin,PVP_M_det_avg[s_det,s_s,3],PVP_M_det_avg[s_det,s_s,2], $
					PVP_I_det_avg[s_det,s_s,1,0],PVP_I_det_avg[s_det,s_s,1,1], $
					PVP_I_det_avg[s_det,s_s,0,0],PVP_I_det_avg[s_det,s_s,0,1], $
					PVP_M_det_avg[s_det,s_s,0],PVP_M_det_avg[s_det,s_s,1], $
					PVP_M_det_avg[s_det,s_s,4],PVP_M_det_avg[s_det,s_s,5],format=fmt
			ENDFOR
		ENDFOR
	ENDIF ELSE BEGIN
		FOR iflag=0, 1 DO BEGIN
			FOR s_s=0, n_s-1 DO BEGIN
				FOR s_det=0, n_det-1 DO BEGIN
					printf,lun,XF_dn_M_det_avg_g[s_det,s_s,3,1-iflag,1], $
						XF_dn_M_det_avg_g[s_det,s_s,2,1-iflag,1], $
						XF_dn_I_det_avg_g[s_det,s_s,1,0,1-iflag,1], $
						XF_dn_I_det_avg_g[s_det,s_s,1,1,1-iflag,1], $
						XF_dn_I_det_avg_g[s_det,s_s,0,0,1-iflag,1], $
						XF_dn_I_det_avg_g[s_det,s_s,0,1,1-iflag,1], $
						XF_dn_M_det_avg_g[s_det,s_s,0,1-iflag,1], $
						XF_dn_M_det_avg_g[s_det,s_s,1,1-iflag,1], $
						XF_dn_M_det_avg_g[s_det,s_s,4,1-iflag,1], $
						XF_dn_M_det_avg_g[s_det,s_s,5,1-iflag,1],format=fmt
					printf,lon,XF_L_M_det_avg_g[s_det,s_s,3,1-iflag,1], $
						XF_L_M_det_avg_g[s_det,s_s,2,1-iflag,1], $
						XF_L_I_det_avg_g[s_det,s_s,1,0,1-iflag,1], $
						XF_L_I_det_avg_g[s_det,s_s,1,1,1-iflag,1], $
						XF_L_I_det_avg_g[s_det,s_s,0,0,1-iflag,1], $
						XF_L_I_det_avg_g[s_det,s_s,0,1,1-iflag,1], $
						XF_L_M_det_avg_g[s_det,s_s,0,1-iflag,1], $
						XF_L_M_det_avg_g[s_det,s_s,1,1-iflag,1], $
						XF_L_M_det_avg_g[s_det,s_s,4,1-iflag,1], $
						XF_L_M_det_avg_g[s_det,s_s,5,1-iflag,1],format=fmt
					printf,len,CNR_M_det_avg_g[s_det,s_s,3,1-iflag,1], $
						CNR_M_det_avg_g[s_det,s_s,2,1-iflag,1], $
						CNR_I_det_avg_g[s_det,s_s,1,0,1-iflag,1], $
						CNR_I_det_avg_g[s_det,s_s,1,1,1-iflag,1], $
						CNR_I_det_avg_g[s_det,s_s,0,0,1-iflag,1], $
						CNR_I_det_avg_g[s_det,s_s,0,1,1-iflag,1], $
						CNR_M_det_avg_g[s_det,s_s,0,1-iflag,1], $
						CNR_M_det_avg_g[s_det,s_s,1,1-iflag,1], $
						CNR_M_det_avg_g[s_det,s_s,4,1-iflag,1], $
						CNR_M_det_avg_g[s_det,s_s,5,1-iflag,1],format=fmt
					printf,lin,PVP_M_det_avg_g[s_det,s_s,3,1-iflag,1], $
						PVP_M_det_avg_g[s_det,s_s,2,1-iflag,1], $
						PVP_I_det_avg_g[s_det,s_s,1,0,1-iflag,1], $
						PVP_I_det_avg_g[s_det,s_s,1,1,1-iflag,1], $
						PVP_I_det_avg_g[s_det,s_s,0,0,1-iflag,1], $
						PVP_I_det_avg_g[s_det,s_s,0,1,1-iflag,1], $
						PVP_M_det_avg_g[s_det,s_s,0,1-iflag,1], $
						PVP_M_det_avg_g[s_det,s_s,1,1-iflag,1], $
						PVP_M_det_avg_g[s_det,s_s,4,1-iflag,1], $
						PVP_M_det_avg_g[s_det,s_s,5,1-iflag,1],format=fmt
					printf,lun_2,XF_dn_M_det_avg_g[s_det,s_s,3,1-iflag,0], $
						XF_dn_M_det_avg_g[s_det,s_s,2,1-iflag,0], $
						XF_dn_I_det_avg_g[s_det,s_s,1,0,1-iflag,0], $
						XF_dn_I_det_avg_g[s_det,s_s,1,1,1-iflag,0], $
						XF_dn_I_det_avg_g[s_det,s_s,0,0,1-iflag,0], $
						XF_dn_I_det_avg_g[s_det,s_s,0,1,1-iflag,0], $
						XF_dn_M_det_avg_g[s_det,s_s,0,1-iflag,0], $
						XF_dn_M_det_avg_g[s_det,s_s,1,1-iflag,0], $
						XF_dn_M_det_avg_g[s_det,s_s,4,1-iflag,0], $
						XF_dn_M_det_avg_g[s_det,s_s,5,1-iflag,0],format=fmt
					printf,lon_2,XF_L_M_det_avg_g[s_det,s_s,3,1-iflag,0], $
						XF_L_M_det_avg_g[s_det,s_s,2,1-iflag,0], $
						XF_L_I_det_avg_g[s_det,s_s,1,0,1-iflag,0], $
						XF_L_I_det_avg_g[s_det,s_s,1,1,1-iflag,0], $
						XF_L_I_det_avg_g[s_det,s_s,0,0,1-iflag,0], $
						XF_L_I_det_avg_g[s_det,s_s,0,1,1-iflag,0], $
						XF_L_M_det_avg_g[s_det,s_s,0,1-iflag,0], $
						XF_L_M_det_avg_g[s_det,s_s,1,1-iflag,0], $
						XF_L_M_det_avg_g[s_det,s_s,4,1-iflag,0], $
						XF_L_M_det_avg_g[s_det,s_s,5,1-iflag,0],format=fmt
					printf,len_2,CNR_M_det_avg_g[s_det,s_s,3,1-iflag,0], $
						CNR_M_det_avg_g[s_det,s_s,2,1-iflag,0], $
						CNR_I_det_avg_g[s_det,s_s,1,0,1-iflag,0], $
						CNR_I_det_avg_g[s_det,s_s,1,1,1-iflag,0], $
						CNR_I_det_avg_g[s_det,s_s,0,0,1-iflag,0], $
						CNR_I_det_avg_g[s_det,s_s,0,1,1-iflag,0], $
						CNR_M_det_avg_g[s_det,s_s,0,1-iflag,0], $
						CNR_M_det_avg_g[s_det,s_s,1,1-iflag,0], $
						CNR_M_det_avg_g[s_det,s_s,4,1-iflag,0], $
						CNR_M_det_avg_g[s_det,s_s,5,1-iflag,0],format=fmt
					printf,lin_2,PVP_M_det_avg_g[s_det,s_s,3,1-iflag,0], $
						PVP_M_det_avg_g[s_det,s_s,2,1-iflag,0], $
						PVP_I_det_avg_g[s_det,s_s,1,0,1-iflag,0], $
						PVP_I_det_avg_g[s_det,s_s,1,1,1-iflag,0], $
						PVP_I_det_avg_g[s_det,s_s,0,0,1-iflag,0], $
						PVP_I_det_avg_g[s_det,s_s,0,1,1-iflag,0], $
						PVP_M_det_avg_g[s_det,s_s,0,1-iflag,0], $
						PVP_M_det_avg_g[s_det,s_s,1,1-iflag,0], $
						PVP_M_det_avg_g[s_det,s_s,4,1-iflag,0], $
						PVP_M_det_avg_g[s_det,s_s,5,1-iflag,0],format=fmt
				ENDFOR
			ENDFOR
		ENDFOR
	ENDELSE

	Free_Lun,lun
	close,/all

	skip_loop:
ENDFOR

close,/all

END
