;*****************************************************************************
;				NICST TOOL
;
;  FP-13 Static SMWIR Xtalk test. Calculate XF_dn, XF_L, and CNR.
;
;  INPUTS:
;  1) inpath -- path to directory with dumped files from a specific UAID.
;  
;  v1.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO fp_13_SMWIR_read_dn_ev, inpath

; Get list of .dmp files from specified path. 
spawn, 'ls -C1 ' + inpath + '*.dmp', list_files
IF N_ELEMENTS(list_files) EQ 0 THEN goto,skipout
nfile=N_ELEMENTS(list_files)

n_bands=8					; # of bands.
n_collects=nfile/8				; # of collects.
n_subset=2					; # subsets (I bands both indices; M bands only use the first index).
n_ham=2						; # HAM sides.
n_gain=2					; # of gain states (always 1 for single gain, 0=high and 1=low for dual gain).
shutter=fltarr(n_collects)			; Records shutter order per collect.
band_info=fltarr(n_collects,n_bands,3)		; Records # of detectors, scans per band, and gain type.
high_det=fltarr(n_collects,2)			; Records the high detector number and associated band number.
high_det[*,1]=-1
band_skip=fltarr(nfile)				; Records which files have no data.
det_low_gain=fltarr(n_collects,n_bands,32)	; Records which detector are on low gain for dual gain bands in auto mode.

bandname=['I3','I4','M10','M11','M12','M13','M8','M9']
band_gain=[1,1,1,1,1,2,1,1]
outfile=' '					; Output file name, which is reasigned.

; DN values per collect (32 possible detectors and 64 possible scans).
dn_collect=dblarr(n_collects,n_bands,n_ham,32,n_subset,n_gain,64)
std_collect=dblarr(n_collects,n_bands,n_ham,32,n_subset,n_gain,64)
dn=dblarr(n_collects,n_bands,32,n_subset)
std=dblarr(n_collects,n_bands,32,n_subset)

;*****************************************************************************
;  Main program. Read data from dump files.
;*****************************************************************************

FOR ifile=0, nfile-1 DO BEGIN

	print,list_files[ifile]
	nlines=File_Lines(list_files[ifile])
	band_skip[ifile]=0
	IF nlines EQ 0 THEN BEGIN
		band_skip[ifile]=1
		goto,skip
	ENDIF

	read_dmpd,list_files[ifile],uaid,collect,scan,ham,apid,band,dnb_s,det,dsect,frame,offset,gain_type,dns

	max_scan=max(scan)		; Total # scans.
	max_det=max(det)		; Total # detectors.
	max_frame=max(frame)+1		; Total # frames.

	; Determine if it is M or I band.
	a2=strsplit(list_files[ifile],'/',/Extract)
	a3=N_ELEMENTS(a2)
	a4=strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)+1,1)

	; Determine the collect #.
	a5=fix(strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)-3,3))

	; Output file name.
	outfile='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/'+strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+1,8)

	; Translate the band name to a number.
	IF band[0] EQ 'I3' THEN b=0
	IF band[0] EQ 'I4' THEN b=1
	IF band[0] EQ 'M10' THEN b=2
	IF band[0] EQ 'M11' THEN b=3
	IF band[0] EQ 'M12' THEN b=4
	IF band[0] EQ 'M13' THEN b=5
	IF band[0] EQ 'M8' THEN b=6
	IF band[0] EQ 'M9' THEN b=7

;*****************************************************************************
;  Write DN values to an array.
;*****************************************************************************

	dn_frame=dblarr(n_ham,max_det,n_subset,n_gain,max_scan,max_frame)
	g=1
	iscan=0
	idet=0
	iframe=0
	subset=0
	FOR i=0L, nlines-1 DO BEGIN
		IF scan[i] EQ iscan+1 AND det[i] EQ idet+1 THEN BEGIN
			dn_frame[ham[i],idet,subset,gain_type[i],iscan,iframe]=dns[i]
			iframe=iframe+1
			IF iframe EQ max_frame THEN BEGIN
				idet=idet+1
				iframe=0
				IF idet EQ max_det THEN BEGIN
					idet=0
					iscan=iscan+1
				ENDIF
			ENDIF
		ENDIF
		IF a4 EQ 'I' THEN BEGIN
			IF subset EQ 0 THEN BEGIN
				subset=1
				goto,skip_over
			ENDIF
			IF subset EQ 1 THEN subset=0
			skip_over:
		ENDIF

		IF gain_type[i] EQ 0 THEN g=0
	ENDFOR

;*****************************************************************************
;  Average over frames.
;*****************************************************************************

	dn_frame_avg=dblarr(n_ham,max_det,n_subset,n_gain,max_scan)
	std_frame_avg=dblarr(n_ham,max_det,n_subset,n_gain,max_scan)
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				FOR igain=0, n_gain-1 DO BEGIN
					FOR iscan=0, max_scan-1 DO BEGIN
						dn_frame_avg[iham,idet,isubset,igain,iscan]= $
							sig_mean(dn_frame[iham,idet,isubset,igain,iscan,0:max_frame-1],3,1)
						std_frame_avg[iham,idet,isubset,igain,iscan]= $
							sig_mean(dn_frame[iham,idet,isubset,igain,iscan,0:max_frame-1],3,2)

						IF std_frame_avg[iham,idet,isubset,igain,iscan] EQ 0 THEN BEGIN
							dn_frame_avg[iham,idet,isubset,igain,iscan]= $
								sig_mean_no_kick(dn_frame[iham,idet,isubset,igain, $
									iscan,0:max_frame-1],1)
							std_frame_avg[iham,idet,isubset,igain,iscan]= $
								sig_mean_no_kick(dn_frame[iham,idet,isubset,igain, $
									iscan,0:max_frame-1],2)
						ENDIF
						IF dn_frame_avg[iham,idet,isubset,igain,iscan] EQ -999 THEN BEGIN
							dn_frame_avg[iham,idet,isubset,igain,iscan]=0
						ENDIF
						IF std_frame_avg[iham,idet,isubset,igain,iscan] EQ -999 THEN BEGIN
							std_frame_avg[iham,idet,isubset,igain,iscan]=0
						ENDIF
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Pick out the detector with the open shutter and shutter order.
;*****************************************************************************

	IF band_gain[b] EQ 1 THEN cutoff=1000
	IF band_gain[b] EQ 2 AND g EQ 1 THEN cutoff=2000
	IF band_gain[b] EQ 2 AND g EQ 0 THEN cutoff=5000

	; Only consider subset=0.
	count=0
	order=fltarr(4)
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			count2=0
			FOR igain=0, n_gain-1 DO BEGIN
				FOR iscan=0, 3 DO BEGIN
					IF dn_frame_avg[iham,idet,0,igain,iscan] GT 4000 THEN BEGIN
						count2=count2+1

						; Fixed low gain.
						IF count2 EQ 2 THEN band_info[a5-1,b,2]=2
					ENDIF
					IF dn_frame_avg[iham,idet,0,igain,iscan] GT cutoff THEN BEGIN
						high_det[a5-1,0]=b
						high_det[a5-1,1]=idet
						count=count+1
						order[iscan]=1

						IF count EQ 2 THEN goto,M_high_det_found
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
	M_high_det_found:

	IF b EQ n_bands-1 AND high_det[a5-1,1] EQ -1 THEN BEGIN
		high_det[a5-1,0]=high_det[a5-2,0]
		high_det[a5-1,1]=high_det[a5-2,1]
	ENDIF

	IF band_info[a5-1,b,2] NE 2 AND g EQ 0 THEN BEGIN
		band_info[a5-1,b,2]=0		; Auto gain; low gain for illuminated detector.
	ENDIF 
	IF band_info[a5-1,b,2] NE 2 AND g EQ 1 THEN BEGIN
		band_info[a5-1,b,2]=1		; Auto gain; high gain for illuminated detector.
	ENDIF

;*****************************************************************************
;  Write data to arrays that can be used later.
;*****************************************************************************

	det_low_gain[a5-1,b,*]=0
	IF band_gain[b] EQ 2 AND band_info[a5-1,b,2] EQ 0 THEN BEGIN
		FOR iham=0, n_ham-1 DO BEGIN
			FOR idet=0, max_det-1 DO BEGIN
				FOR igain=0, n_gain-1 DO BEGIN
					FOR iscan=0, 3 DO BEGIN
						IF dn_frame_avg[iham,idet,0,igain,iscan] GT 4000 THEN BEGIN
							det_low_gain[a5-1,b,idet]=1
						ENDIF
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDIF

	IF b EQ 0 THEN shutter[a5-1]=-1
	IF order[0] EQ 1 AND order[1] EQ 1 THEN shutter[a5-1]=1
	IF order[0] EQ 1 AND order[3] EQ 1 THEN shutter[a5-1]=2
	IF order[1] EQ 1 AND order[2] EQ 1 THEN shutter[a5-1]=3
	IF order[2] EQ 1 AND order[3] EQ 1 THEN shutter[a5-1]=4
	IF b EQ n_bands-1 AND shutter[a5-1] EQ -1 THEN shutter[a5-1]=shutter[a5-2]

	band_info[a5-1,b,0]=max_det
	band_info[a5-1,b,1]=max_scan
	FOR iham=0, n_ham-1 DO BEGIN
		FOR idet=0, max_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				FOR igain=0, n_gain-1 DO BEGIN
					FOR iscan=0, max_scan-1 DO BEGIN
						dn_collect[a5-1,b,iham,idet,isubset,igain,iscan]= $
							dn_frame_avg[iham,idet,isubset,igain,iscan]
						std_collect[a5-1,b,iham,idet,isubset,igain,iscan]= $
							std_frame_avg[iham,idet,isubset,igain,iscan]
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

	skip:
ENDFOR

;*****************************************************************************
;  Read gains from a file to an array.
;*****************************************************************************

openr,lun,'/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/gain_SMWIR.dat',/get_lun

n_lines=File_Lines('/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/gain_SMWIR.dat')
IF n_lines EQ 0 THEN goto,skipout

awa=''
b_name=strarr(n_lines)			; Band name.
ham_side=fltarr(n_lines)		; HAM side.
detector=fltarr(n_lines)		; detector.
subframe=fltarr(n_lines)		; BSubframe.
g=fltarr(n_lines)			; Gain.	

FOR ix=0L, n_lines-1 DO BEGIN
	readf,lun,awa
	a1=strsplit(awa,String(9B),/Extract)
	b_name(ix)=a1(0)
	ham_side(ix)=a1(2)-1
	detector(ix)=a1(3)-1
	subframe(ix)=a1(4)-1
	g(ix)=a1(6)
ENDFOR

close,lun,/file,/all
free_lun,lun

gain_temp=fltarr(n_bands,n_ham,32,n_gain,n_subset)
gain=fltarr(n_bands,32,n_gain,n_subset)
FOR i=0L, n_lines-1 DO BEGIN
	IF b_name[i] EQ 'I3' THEN BEGIN
		gain_temp[0,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'I4' THEN BEGIN
		gain_temp[1,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M10' THEN BEGIN
		gain_temp[2,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M11' THEN BEGIN
		gain_temp[3,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M12' THEN BEGIN
		gain_temp[4,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M13' AND g[i] GT 100 THEN BEGIN 	;High gain.
		gain_temp[5,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M13' AND g[i] LT 100 THEN BEGIN 	;Low gain.
		gain_temp[5,ham_side[i],detector[i],0,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M8' THEN BEGIN
		gain_temp[6,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
	IF b_name[i] EQ 'M9' THEN BEGIN
		gain_temp[7,ham_side[i],detector[i],1,subframe[i]]=g[i]
	ENDIF
ENDFOR
gain[*,*,*,*]=(gain_temp[*,0,*,*,*]+gain_temp[*,1,*,*,*])/2

;*****************************************************************************
;  Average over scans and HAM side (since it is a staring test).
;*****************************************************************************

FOR collect=0, n_collects-1 DO BEGIN

	temp=fltarr(4)
	temp2=fltarr(4)
	IF shutter[collect] EQ 1 THEN alpha=[1,1,-1,-1]
	IF shutter[collect] EQ 2 THEN alpha=[1,-1,-1,1]
	IF shutter[collect] EQ 3 THEN alpha=[-1,1,1,-1]
	IF shutter[collect] EQ 4 THEN alpha=[-1,-1,1,1]

	; Use low gain background from fixed low collects for auto low gain
	; when sender is in low gain. Usually +2 collects.
	IF collect+2 GE n_collects THEN goto,skip_coll
	IF shutter[collect+2] EQ 1 THEN beta=[1,1,-1,-1]
	IF shutter[collect+2] EQ 2 THEN beta=[1,-1,-1,1]
	IF shutter[collect+2] EQ 3 THEN beta=[-1,1,1,-1]
	IF shutter[collect+2] EQ 4 THEN beta=[-1,-1,1,1]
	skip_coll:

;UAID 3102168
;	IF collect EQ 3 THEN BEGIN
;		IF shutter[collect-1] EQ 1 THEN gamma=[1,1,-1,-1]
;		IF shutter[collect-1] EQ 2 THEN gamma=[1,-1,-1,1]
;		IF shutter[collect-1] EQ 3 THEN gamma=[-1,1,1,-1]
;		IF shutter[collect-1] EQ 4 THEN gamma=[-1,-1,1,1]
;	ENDIF

;UAID 3102165
	; For (fixed low) collect 54 the shutter did not close.
	; Use fixed low background from the collect 57. 
;	IF collect EQ 51 OR collect EQ 53 THEN BEGIN
;		IF shutter[56] EQ 1 THEN gamma=[1,1,-1,-1]
;		IF shutter[56] EQ 2 THEN gamma=[1,-1,-1,1]
;		IF shutter[56] EQ 3 THEN gamma=[-1,1,1,-1]
;		IF shutter[56] EQ 4 THEN gamma=[-1,-1,1,1]

;		IF collect EQ 53 THEN BEGIN
;			IF shutter[51] EQ 1 THEN temp2=[1,1,-1,-1]
;			IF shutter[51] EQ 2 THEN temp2=[1,-1,-1,1]
;			IF shutter[51] EQ 3 THEN temp2=[-1,1,1,-1]
;			IF shutter[51] EQ 4 THEN temp2=[-1,-1,1,1]
;		ENDIF
;	ENDIF

	FOR b=0, n_bands-1 DO BEGIN
		m_det=band_info[collect,b,0]
		m_scan=band_info[collect,b,1]
		m_gain=band_info[collect,b,2]

		IF m_gain EQ 0 THEN igain=1
		IF m_gain EQ 1 THEN igain=1
		IF m_gain EQ 2 THEN igain=0

		FOR idet=0, m_det-1 DO BEGIN
			FOR isubset=0, n_subset-1 DO BEGIN
				count=0
				FOR iscan=0, m_scan-4 DO BEGIN
					IF (m_gain EQ 0 AND det_low_gain[collect,b,idet] EQ 1) THEN BEGIN

						;UAID 3102168
				;		IF collect EQ 3 THEN BEGIN
				;			temp[*]=gamma[*]
				;			index=-1
				;		ENDIF
				;		IF collect NE 3 THEN index=2

					; UAID 3102165
				;	IF (m_gain EQ 0 AND det_low_gain[collect,b,idet] EQ 1) OR $
				;		(collect EQ 53 AND fix(high_det[53,1]) EQ idet AND b EQ 5) THEN BEGIN
	
				;		IF collect NE 51 AND collect NE 53 THEN BEGIN
				;			temp[*]=beta[*]
				;			index=2
				;		ENDIF
				;		IF collect EQ 51 THEN BEGIN
				;			temp[*]=gamma[*]
				;			index=5
				;		ENDIF
				;		IF collect EQ 53 THEN BEGIN
				;			temp[*]=gamma[*]						
				;			alpha[*]=temp2[*]
				;			index=3
				;		ENDIF

						FOR iham=0, n_ham-1 DO BEGIN
							dn[collect,b,idet,isubset]=dn[collect,b,idet,isubset] $
								+((1+alpha[0])/2*dn_collect[collect,b,iham,idet, $
									isubset,0,iscan] $
								+(1+alpha[1])/2*dn_collect[collect,b,iham,idet, $
									isubset,0,iscan+1] $
								+(1+alpha[2])/2*dn_collect[collect,b,iham,idet, $
									isubset,0,iscan+2] $
								+(1+alpha[3])/2*dn_collect[collect,b,iham,idet, $
									isubset,0,iscan+3] $
								-(1-temp[0])/2*dn_collect[collect+index,b,iham,idet, $
									isubset,0,iscan] $
								-(1-temp[1])/2*dn_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+1] $
								-(1-temp[2])/2*dn_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+2] $
								-(1-temp[3])/2*dn_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+3])
	
							std[collect,b,idet,isubset]=std[collect,b,idet,isubset] $
								+(1-temp[0])/2*std_collect[collect+index,b,iham,idet, $
									isubset,0,iscan] $
								+(1-temp[1])/2*std_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+1] $
								+(1-temp[2])/2*std_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+2] $
								+(1-temp[3])/2*std_collect[collect+index,b,iham,idet, $
									isubset,0,iscan+3]
						ENDFOR
					ENDIF ELSE BEGIN
						FOR iham=0, n_ham-1 DO BEGIN
							dn[collect,b,idet,isubset]=dn[collect,b,idet,isubset] $
								+(alpha[0]*dn_collect[collect,b,iham,idet,isubset,igain,iscan] $
								+alpha[1]*dn_collect[collect,b,iham,idet,isubset,igain,iscan+1] $
								+alpha[2]*dn_collect[collect,b,iham,idet,isubset,igain,iscan+2] $
								+alpha[3]*dn_collect[collect,b,iham,idet,isubset,igain,iscan+3])
	
							std[collect,b,idet,isubset]=std[collect,b,idet,isubset] $
								+(1-alpha[0])/2*std_collect[collect,b,iham,idet, $
									isubset,igain,iscan] $
								+(1-alpha[1])/2*std_collect[collect,b,iham,idet, $
									isubset,igain,iscan+1] $
								+(1-alpha[2])/2*std_collect[collect,b,iham,idet, $
									isubset,igain,iscan+2] $
								+(1-alpha[3])/2*std_collect[collect,b,iham,idet, $
									isubset,igain,iscan+3]
						ENDFOR
					ENDELSE

					iscan=iscan+3
					count=count+2
					IF iscan EQ m_scan-1 THEN BEGIN
						dn[collect,b,idet,isubset]=dn[collect,b,idet,isubset]/count
						std[collect,b,idet,isubset]=std[collect,b,idet,isubset]/count
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
	save,/compress,high_det,det_low_gain,band_info,dn,std,filename=outfile+'.dn.sav'
ENDFOR

;print,dn[0,5,*,0]
;*****************************************************************************
;  Output DN to files for I and M bands.
;*****************************************************************************

fmt_1='(i3, 5x, a5, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d)'
fmt_2='(i3, 5x, a5, 5x, i2, 5x, d, 5x, d)'

; Output numbers to a data file.
openw,lun,outfile+'_I.dat',/get_lun
openw,lon,outfile+'_M.dat',/get_lun
printf,lun,'Collect  Band  Detector  DN(sub=0)    DN(sub=1)   STD(sub=0)    STD(sub=1)'
printf,lon,'Collect  Band  Detector  DN     STD'
FOR collect=0, n_collects-1 DO BEGIN
	FOR ib=0, 7 DO BEGIN
		ifile=8*collect+ib
		IF band_skip[ifile] EQ 1 THEN goto,skip_band
		FOR idet=0, 31 DO BEGIN
			IF ib LE 1 THEN printf,lun,format=fmt_1,collect+1,bandname[ib],idet+1, $
				dn[collect,ib,idet,0],dn[collect,ib,idet,1],std[collect,ib,idet,0],std[collect,ib,idet,1]
			IF ib GT 1 AND idet EQ 16 THEN goto,skip_det
			IF ib GT 1 THEN printf,lon,format=fmt_2,collect+1,bandname[ib],idet+1, $
				dn[collect,ib,idet,0],std[collect,ib,idet,0]
		ENDFOR
		skip_det:
		skip_band:
	ENDFOR
ENDFOR
close,lun,/file,/all
free_lun,lun

;*****************************************************************************
;  Calculate crosstalk parameters and write to an output file.
;*****************************************************************************

fmt='(i3, 5x, a5, 5x, i2, 5x, i2, 5x, a5, 5x, i2, 5x, i2, 5x, d, 5x, d, 5x, d, 5x, d, 5x, d)'

L_max_hg=3.47
L_max_lg=404.891
L_typ_hg=0.79
L_typ_lg=9.53
L_max=[72.5,3.014,71.2,31.80,2.827,L_max_hg,164.9,77.1]
L_typ=[7.3,0.11,7.3,0.12,0.1,L_typ_hg,5.4,6]

XF_dn=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
XF_L=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
CNR=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP_1=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)
PVP_2=fltarr(n_collects,32,n_subset,n_bands,32,n_subset)

openw,lun,outfile+'_coeff.dat',/get_lun
printf,lun,'Collect  S_Band  S_Detector  S_Subset  R_Band  R_Detector  R_Subset   XF_dn   XF_L   CNR   CNR_1   CNR_2'
FOR collect=0, n_collects-1 DO BEGIN

	; Sender band (s_band), ham (iham), detector (s_det), and subset (isubset).
	s_band=high_det[collect,0]
	s_det=fix(high_det[collect,1])

	; L_max of sender detector (for dual gain bands).
	L_max[5]=L_max_hg
	IF band_info[collect,s_band,2] NE 1 THEN L_max[5]=L_max_lg
	L_typ[5]=L_typ_hg
	IF band_info[collect,s_band,2] NE 1 THEN L_typ[5]=L_typ_lg

	IF band_info[collect,s_band,2] NE 1 THEN s_gain=0
	IF band_info[collect,s_band,2] EQ 1 THEN s_gain=1

	IF s_band LE 1 THEN n_subset=2
	IF s_band GT 1 THEN n_subset=1
	FOR isubset=0, n_subset-1 DO BEGIN

		; Receiver band (ib), ham (ih), detector (id), and subset (is).
		FOR ib=0, 7 DO BEGIN
			ifile_r=8*collect+ib
			IF band_skip[ifile_r] EQ 1 THEN goto,skip_band_r
			n_d=band_info[collect,ib,0]
			FOR id=0, n_d-1 DO BEGIN
				IF band_info[collect,ib,2] EQ 0 THEN BEGIN
					IF det_low_gain[collect,ib,id] EQ 1 THEN ig=0
					IF det_low_gain[collect,ib,id] EQ 0 THEN ig=1
				ENDIF
				IF band_info[collect,ib,2] EQ 1 THEN ig=1
				IF band_info[collect,ib,2] EQ 2 THEN ig=0

				IF ib LE 1 THEN n_subset=2
				IF ib GT 1 THEN n_subset=1
				FOR is=0, n_subset-1 DO BEGIN
					dn_snd_band=total(dn[collect,s_band,*,isubset])

					IF dn[collect,s_band,s_det,isubset] EQ 0 THEN BEGIN
						dn[collect,s_band,s_det,isubset]=1000000.0
					ENDIF
					XF_dn[collect,s_det,isubset,ib,id,is]= $
						dn[collect,ib,id,is]/dn_snd_band
					XF_L[collect,s_det,isubset,ib,id,is]= $
						gain[s_band,s_det,s_gain,isubset]*dn[collect,ib,id,is]/ $
						(gain[ib,id,ig,is]*dn_snd_band)
					PVP_1[collect,s_det,isubset,ib,id,is]= $
						2*sqrt(3)*L_max[s_band]*dn[collect,ib,id,is]* $
						gain[s_band,s_det,s_gain,isubset]/(dn_snd_band*std[collect,ib,id,is])
					PVP_2[collect,s_det,isubset,ib,id,is]= $
						L_max[s_band]*dn[collect,ib,id,is]*gain[s_band,s_det,s_gain,isubset]/ $
						(dn_snd_band*gain[ib,id,ig,is]*0.002*L_typ[ib])
					IF ib EQ 5 THEN BEGIN
						PVP_1[collect,s_det,isubset,ib,id,is]= $
							2*L_max[s_band]*dn[collect,ib,id,is]* $
							gain[s_band,s_det,s_gain,isubset]/(dn_snd_band*std[collect,ib,id,is])
					ENDIF
					IF abs(PVP_2[collect,s_det,isubset,ib,id,is]) GT $
						abs(PVP_1[collect,s_det,isubset,ib,id,is]) THEN BEGIN
						PVP[collect,s_det,isubset,ib,id,is]=PVP_1[collect,s_det,isubset,ib,id,is]
					ENDIF ELSE BEGIN
						PVP[collect,s_det,isubset,ib,id,is]=PVP_2[collect,s_det,isubset,ib,id,is]
					ENDELSE
					CNR[collect,s_det,isubset,ib,id,is]=PVP_1[collect,s_det,isubset,ib,id,is]/4
					printf,lun,format=fmt,collect+1,bandname[s_band], $
						s_det+1,isubset,bandname[ib],id+1,is, $
						XF_dn[collect,s_det,isubset,ib,id,is], $
						XF_L[collect,s_det,isubset,ib,id,is], $
						CNR[collect,s_det,isubset,ib,id,is], $
						PVP[collect,s_det,isubset,ib,id,is]
				ENDFOR
			ENDFOR
			skip_band_r:
		ENDFOR
	ENDFOR
	save,/compress,gain,XF_dn,XF_L,CNR,PVP,filename=outfile+'.coeff.sav'
ENDFOR
close,lun,/file,/all
free_lun,lun

skipout:

END
