;*****************************************************************************
;				NICST TOOL
;
;  Graphs dn and three influence coefficients as a function of detectors and
;  also in focal plane order.
;  
;  v1.0 - 10/7/2007 - Chunhui Pan
;  v2.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO view_sf_SMWIR

close,/all

band_name=['I3 SS1','I3 SS2','I4 SS1','I4 SS2','M10','M11','M12','M13','M8','M9']
band_name_2=['I3','I4','M10','M11','M12','M13','M8','M9']
ibindx=[0]
n_gain=[0,0,0,0,0,0,0,1,0,0]
nband=n_elements(band_name)
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)

i=0
ibdet2=fltarr(32)
FOR x=0,ndet_I-1 DO BEGIN
    ibdet2[i]=float(x)/2+1.0
    i=i+1
ENDFOR

uaidname=['3102097','3102104','3102107','3102118','3102124','3102150','3102163','3102164','3102165','3102168','3102193']
n_uaid=N_ELEMENTS(uaidname)
colnum=[33,36,69,33,39,66,8,28,57,49,33]
tick_name=[' ','M13','M12','I4_1','I4_2','I3_1','I3_2','M10','M11','M8','M9',' ']

;*****************************************************************************
;  Read in data, skip bad collects, and reform data.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,2,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.dn.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.coeff.sav'
;	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.snd_avg_coeff.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	FOR col=0, colnum[uaid]-1 DO BEGIN

		; U3102097
		IF uaidname[uaid] EQ '3102097' THEN BEGIN
			IF col EQ 16 THEN goto,skip_col
		ENDIF

		; U3102104
		IF uaidname[uaid] EQ '3102104' THEN BEGIN
			IF col EQ 18 OR col EQ 19 OR col EQ 22 OR col EQ 23 THEN goto,skip_col
		ENDIF

		; U3102107
		IF uaidname[uaid] EQ '3102107' THEN BEGIN
			IF col EQ 4 OR col EQ 23 OR col EQ 24 OR col EQ 41 OR col EQ 64 THEN goto,skip_col
		ENDIF

		; U3102118
		IF uaidname[uaid] EQ '3102118' THEN BEGIN
			IF col EQ 4 THEN goto,skip_col
		ENDIF

		; U3102124
		IF uaidname[uaid] EQ '3102124' THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 2 OR col EQ 4 OR col EQ 6 OR col EQ 7 $
				OR col EQ 8 OR col EQ 10 OR col EQ 12 OR col EQ 14 OR col EQ 15 $
				OR col EQ 17 OR col EQ 19 OR col EQ 21 OR col EQ 23 OR col EQ 25 $
				OR col EQ 26 OR col EQ 28 OR col EQ 30 OR col EQ 32 OR col EQ 34 $
				OR col EQ 36 OR col EQ 38 THEN goto,skip_col
		ENDIF

		; U3102150
		IF uaidname[uaid] EQ '3102150' THEN BEGIN
			IF col EQ 0 OR col EQ 53 THEN goto,skip_col
		ENDIF

		; U3102163
		IF uaidname[uaid] EQ '3102163' THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 3 OR col EQ 4 OR col EQ 5 OR col EQ 7 $
				THEN goto,skip_col
		ENDIF

		; U3102164
		IF uaidname[uaid] EQ '3102164' THEN BEGIN
			IF col EQ 1 OR col EQ 3 OR col EQ 5 OR col EQ 7 OR col EQ 9 OR col EQ 11 $
				OR col EQ 13 OR col EQ 15 OR col EQ 17 OR col EQ 19 OR col EQ 21 $
				OR col EQ 23 OR col EQ 25 OR col EQ 27 THEN goto,skip_col
		ENDIF

		; U3102165
		IF uaidname[uaid] EQ '3102165' THEN BEGIN
			IF col EQ 1 OR col EQ 4 OR col EQ 7 OR col EQ 10 OR col EQ 13 OR col EQ 15 $
				OR col EQ 17 OR col EQ 20 OR col EQ 23 OR col EQ 25 OR col EQ 26 $
				OR col EQ 27 OR col EQ 29 OR col EQ 32 OR col EQ 35 OR col EQ 38 $
				OR col EQ 41 OR col EQ 44 OR col EQ 46 OR col EQ 47 OR col EQ 48 $
				OR col EQ 49 OR col EQ 50 OR col EQ 52 OR col EQ 55 THEN goto,skip_col
		ENDIF

		; U3102168
		IF uaidname[uaid] EQ '3102168' THEN BEGIN
			IF col EQ 0 OR col EQ 1 OR col EQ 5 OR col EQ 8 OR col EQ 11 OR col EQ 14 $
				OR col EQ 17 OR col EQ 20 OR col EQ 23 OR col EQ 26 OR col EQ 29 $
				OR col EQ 32 OR col EQ 35 OR col EQ 38 OR col EQ 41 OR col EQ 44 $
				OR col EQ 47 THEN goto,skip_col
		ENDIF

		; U3102193
		IF uaidname[uaid] EQ '3102193' THEN BEGIN
			IF col EQ 0 THEN goto,skip_col
		ENDIF

		band_lit=fix(high_det[col,0])
		det_lit=fix(high_det[col,1])

		dn_I=fltarr(2,ndet_I,2)
		XF_dn_I=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I=fltarr(ndet_I,2,2,ndet_I,2)
		FOR j=0, 1 DO BEGIN
			FOR i=0, ndet_I-1, 2 DO BEGIN
				dn_I[j,i,0]=dn[col,j,i,0]
				dn_I[j,i+1,0]=dn[col,j,i+1,1]
				dn_I[j,i,1]=dn[col,j,i,1]
				dn_I[j,i+1,1]=dn[col,j,i+1,0]

				XF_dn_I[*,*,j,i,0]=XF_dn[col,*,*,j,i,0]*1000
				XF_dn_I[*,*,j,i+1,0]=XF_dn[col,*,*,j,i+1,1]*1000
				XF_dn_I[*,*,j,i,1]=XF_dn[col,*,*,j,i,1]*1000
				XF_dn_I[*,*,j,i+1,1]=XF_dn[col,*,*,j,i+1,0]*1000

				XF_L_I[*,*,j,i,0]=XF_L[col,*,*,j,i,0]*1000
				XF_L_I[*,*,j,i+1,0]=XF_L[col,*,*,j,i+1,1]*1000
				XF_L_I[*,*,j,i,1]=XF_L[col,*,*,j,i,1]*1000
				XF_L_I[*,*,j,i+1,1]=XF_L[col,*,*,j,i+1,0]*1000

				CNR_I[*,*,j,i,0]=CNR[col,*,*,j,i,0]
				CNR_I[*,*,j,i+1,0]=CNR[col,*,*,j,i+1,1]
				CNR_I[*,*,j,i,1]=CNR[col,*,*,j,i,1]
				CNR_I[*,*,j,i+1,1]=CNR[col,*,*,j,i+1,0]
			ENDFOR
		ENDFOR

		dn_M=(reform(dn[col,2:7,*,0]))
		XF_dn_M=(reform(XF_dn[col,*,*,2:7,0:15,0]))*1000
		XF_L_M=(reform(XF_L[col,*,*,2:7,0:15,0]))*1000
		CNR_M=(reform(CNR[col,*,*,2:7,0:15,0]))

		IF band_lit LE 1 THEN n_det=32
		IF band_lit LE 1 THEN n_s=2
		IF band_lit GE 2 THEN n_det=16
		IF band_lit GE 2 THEN n_s=1

		XF_dn_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		XF_L_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		CNR_I_t=fltarr(ndet_I,2,2,ndet_I,2)
		FOR s_s=0, n_s-1 DO BEGIN
			FOR r_s=0, 1 DO BEGIN
				FOR ib=0, 1 DO BEGIN
					IF mean(XF_L_I[det_lit,s_s,ib,*,0]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,1]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,1]
						ENDFOR
					ENDIF
					IF mean(XF_L_I[det_lit,s_s,ib,*,1]) GT $
						mean(XF_L_I[det_lit,s_s,ib,*,0]) THEN BEGIN
						FOR id=0, ndet_I-1 DO BEGIN

							XF_dn_I_t[det_lit,s_s,ib,id,0]=XF_dn_I[det_lit,s_s,ib,id,1]
							XF_dn_I_t[det_lit,s_s,ib,id,1]=XF_dn_I[det_lit,s_s,ib,id,0]
							XF_L_I_t[det_lit,s_s,ib,id,0]=XF_L_I[det_lit,s_s,ib,id,1]
							XF_L_I_t[det_lit,s_s,ib,id,1]=XF_L_I[det_lit,s_s,ib,id,0]
							CNR_I_t[det_lit,s_s,ib,id,0]=CNR_I[det_lit,s_s,ib,id,1]
							CNR_I_t[det_lit,s_s,ib,id,1]=CNR_I[det_lit,s_s,ib,id,0]
						ENDFOR
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
		XF_dn_I[*,*,*,*,*]=XF_dn_I_t[*,*,*,*,*]
		XF_L_I[*,*,*,*,*]=XF_L_I_t[*,*,*,*,*]
		CNR_I[*,*,*,*,*]=CNR_I_t[*,*,*,*,*]

		flag=fltarr(6)
		FOR ib=0, 5 DO BEGIN
			IF mean(dn_M[ib,*]) EQ 0 THEN flag[ib]=1
		ENDFOR

		ymin_1=min(dn_I[*,*,0])
		ymin_2=min(dn_M[*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		ymax_1=max(dn_I[*,*,0])
		ymax_2=max(dn_M[*,*])
		IF ymax_1 GE ymax_2 THEN ymax=ymax_1
		IF ymax_1 LT ymax_2 THEN ymax=ymax_2

		; Plot dn per detector on a log plot.

		plot,ibdet2[*],dn_I[0,*,0],xrange=[0,ndet_M+1],yrange=[0.0001,ymax],ytit='dn',xtit='detector',/nodata,/ylog
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],dn_I[ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib]
			oplot,ibdet2[*],dn_I[ib,*,0],color=lcol[2*ib]
			oplot,ibdet2[*],dn_I[ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1]
			oplot,ibdet2[*],dn_I[ib,*,1],color=lcol[2*ib+1]
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_1
			oplot,det_M[0:15]+1,dn_M[ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4]
			oplot,det_M[0:15]+1,dn_M[ib,0:15],color=lcol[ib+4]
			skip_band_1:
		ENDFOR

		; Plot dn per detector.

		ymax=5

		plot,ibdet2[*],dn_M[0,*],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='dn',xtit='detector',/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],dn_I[ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib]
			oplot,ibdet2[*],dn_I[ib,*,0],color=lcol[2*ib]
			oplot,ibdet2[*],dn_I[ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1]
			oplot,ibdet2[*],dn_I[ib,*,1],color=lcol[2*ib+1]
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_2
			oplot,det_M[0:15]+1,dn_M[ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4]
			oplot,det_M[0:15]+1,dn_M[ib,0:15],color=lcol[ib+4]
			skip_band_2:
		ENDFOR

		; Plot XF_dn per detector.

		ymax=2
		ymin_1=min(XF_dn_I[det_lit,0,*,*,0])
		ymin_2=min(XF_dn_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_dn_I[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_dn*1000', $
			xtit='detector',/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],XF_dn_I[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib]
			oplot,ibdet2[*],XF_dn_I[det_lit,0,ib,*,0],color=lcol[2*ib]
			oplot,ibdet2[*],XF_dn_I[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1]
			oplot,ibdet2[*],XF_dn_I[det_lit,0,ib,*,1],color=lcol[2*ib+1]
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_3
			oplot,det_M[0:15]+1,XF_dn_M[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4]
			oplot,det_M[0:15]+1,XF_dn_M[det_lit,0,ib,0:15],color=lcol[ib+4]
			skip_band_3:
		ENDFOR

		; Plot XF_L per detector.

		ymax=2
		ymin_1=min(XF_L_I[det_lit,0,*,*,0])
		ymin_2=min(XF_L_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_L_I[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_L*1000', $
			xtit='detector',/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],XF_L_I[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib]
			oplot,ibdet2[*],XF_L_I[det_lit,0,ib,*,0],color=lcol[2*ib]
			oplot,ibdet2[*],XF_L_I[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1]
			oplot,ibdet2[*],XF_L_I[det_lit,0,ib,*,1],color=lcol[2*ib+1]
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			IF flag[ib] EQ 1 THEN goto,skip_band_4
			oplot,det_M[0:15]+1,XF_L_M[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4]
			oplot,det_M[0:15]+1,XF_L_M[det_lit,0,ib,0:15],color=lcol[ib+4]
			skip_band_4:
		ENDFOR

		IF uaidname[uaid] EQ '3102159' THEN BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name_2[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDIF ELSE BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name_2[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDELSE
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6     
		set_legend,1,band_name,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0

		; Plot dn per band.

		bandindex_1=findgen(10)+1
		bandindex_2=WHERE(bandindex_1 NE 1 AND bandindex_1 NE 2)+1

		ymax=2
		ymin_1=min(dn_I[*,*,0])
		ymin_2=min(dn_M[*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='dn',/nodata,XTICKS=11,XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-5,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_1,[dn_M[3,idet],dn_M[2,idet],dn_I[1,idet,0],dn_I[1,idet,1], $
						dn_I[0,idet,0],dn_I[0,idet,1],dn_M[0,idet],dn_M[1,idet], $
						dn_M[4,idet],dn_M[5,idet]],symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[dn_M[3,idet],dn_M[2,idet],dn_I[1,idet,0],dn_I[1,idet,1], $
						dn_I[0,idet,0],dn_I[0,idet,1],dn_M[0,idet],dn_M[1,idet], $
						dn_M[4,idet],dn_M[5,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0], $
						dn_I[0,idet,1],dn_M[0,idet],dn_M[1,idet],dn_M[4,idet],dn_M[5,idet]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0], $
						dn_I[0,idet,1],dn_M[0,idet],dn_M[1,idet],dn_M[4,idet],dn_M[5,idet]], $
						color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0],dn_I[0,idet,1]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0],dn_I[0,idet,1]], $
						color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0],dn_I[0,idet,1]], $
						symsize=1,color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[dn_I[1,idet,0],dn_I[1,idet,1],dn_I[0,idet,0],dn_I[0,idet,1]], $
						color=lcol[idet]
				ENDIF
			ENDELSE
		ENDFOR

		; Plot XF_dn per band.

		ymax=2
		ymin_1=min(XF_dn_I[det_lit,0,*,*,0])
		ymin_2=min(XF_dn_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='XF_dn*1000',/nodata,XTICKS=11, $
			XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_1,[XF_dn_M[det_lit,0,3,idet],XF_dn_M[det_lit,0,2,idet], $
						XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1], $
						XF_dn_M[det_lit,0,0,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,4,idet],XF_dn_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[XF_dn_M[det_lit,0,3,idet],XF_dn_M[det_lit,0,2,idet], $
						XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1], $
						XF_dn_M[det_lit,0,0,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,4,idet],XF_dn_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1], $
						XF_dn_M[det_lit,0,0,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,4,idet],XF_dn_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1], $
						XF_dn_M[det_lit,0,0,idet],XF_dn_M[det_lit,0,1,idet], $
						XF_dn_M[det_lit,0,4,idet],XF_dn_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_dn_I[det_lit,0,1,idet,0],XF_dn_I[det_lit,0,1,idet,1], $
						XF_dn_I[det_lit,0,0,idet,0],XF_dn_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
			ENDELSE
		ENDFOR

		; Plot XF_L per band.

		ymax=2
		ymin_1=min(XF_L_I[det_lit,0,*,*,*])
		ymin_2=min(XF_L_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='XF_L*1000',/nodata,XTICKS=11, $
			XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_1,[XF_L_M[det_lit,0,3,idet],XF_L_M[det_lit,0,2,idet], $
						XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1], $
						XF_L_M[det_lit,0,0,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,4,idet],XF_L_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[XF_L_M[det_lit,0,3,idet],XF_L_M[det_lit,0,2,idet], $
						XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1], $
						XF_L_M[det_lit,0,0,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,4,idet],XF_L_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1], $
						XF_L_M[det_lit,0,0,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,4,idet],XF_L_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1], $
						XF_L_M[det_lit,0,0,idet],XF_L_M[det_lit,0,1,idet], $
						XF_L_M[det_lit,0,4,idet],XF_L_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[XF_L_I[det_lit,0,1,idet,0],XF_L_I[det_lit,0,1,idet,1], $
						XF_L_I[det_lit,0,0,idet,0],XF_L_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
			ENDELSE
		ENDFOR

		; Plot CNR per band.

		ymax=2
		ymin_1=min(CNR_I[det_lit,0,*,*,0])
		ymin_2=min(CNR_M[det_lit,0,*,*])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='CNR',/nodata,XTICKS=11,XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_1,[CNR_M[det_lit,0,3,idet],CNR_M[det_lit,0,2,idet], $
						CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1], $
						CNR_M[det_lit,0,0,idet],CNR_M[det_lit,0,1,idet], $
						CNR_M[det_lit,0,4,idet],CNR_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_1,[CNR_M[det_lit,0,3,idet],CNR_M[det_lit,0,2,idet], $
						CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1], $
						CNR_M[det_lit,0,0,idet],CNR_M[det_lit,0,1,idet], $
						CNR_M[det_lit,0,4,idet],CNR_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1], $
						CNR_M[det_lit,0,0,idet],CNR_M[det_lit,0,1,idet], $
						CNR_M[det_lit,0,4,idet],CNR_M[det_lit,0,5,idet]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1], $
						CNR_M[det_lit,0,0,idet],CNR_M[det_lit,0,1,idet], $
						CNR_M[det_lit,0,4,idet],CNR_M[det_lit,0,5,idet]],color=lcol[idet]
				ENDIF
			ENDIF ELSE BEGIN
				IF flag[2] EQ 0 THEN BEGIN
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
				IF flag[2] EQ 1 THEN BEGIN
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1]],symsize=1, $
						color=lcol[idet],psym=symbol[idet]
					oplot,bandindex_2,[CNR_I[det_lit,0,1,idet,0],CNR_I[det_lit,0,1,idet,1], $
						CNR_I[det_lit,0,0,idet,0],CNR_I[det_lit,0,0,idet,1]],color=lcol[idet]
				ENDIF
			ENDELSE
		ENDFOR

		IF uaidname[uaid] EQ '3102107' OR uaidname[uaid] EQ '3102150' THEN BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name_2[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDIF ELSE BEGIN
			title='U'+uaidname[uaid]+' Collect '+strtrim(string(col+1),2)+': Illuminated Band '+ $
				strtrim(band_name_2[fix(high_det[col,0])],2)+', Detecter '+ $
				strtrim(string(fix(high_det[col,1]+1)),2)
		ENDELSE
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6
		set_legend,2,chname,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0
	
		skip_col:
	ENDFOR 	;col

	skip_loop:
ENDFOR 	;uaid
device,/close

!p.multi=0
!p.position=0

END
