;*****************************************************************************
;				NICST TOOL
;
;  Graphs three influence coefficients and PVP as a function of detectors and
;  also in focal plane order.
;  
;  v1.0 - 10/7/2007 - Chunhui Pan
;  v2.0 - 11/20/2007 - Jeff McIntire
;*****************************************************************************

PRO view_sf_SMWIR_2

close,/all

band_name=['I3 SS1','I3 SS2','I4 SS1','I4 SS2','M10','M11','M12','M13','M8','M9']
name_band_2=['I3','I4','M10','M11','M12','M13','M8','M9']
ibindx=[0]
n_gain=[0,0,0,0,0,0,0,1,0,0]
nband=n_elements(band_name)
ndet_I=32
ndet_M=16
det_I=findgen(ndet_I)
det_M=findgen(ndet_M)

i=0
ibdet2=fltarr(32)
FOR x=0,ndet_I-1 DO BEGIN
    ibdet2[i]=float(x)/2+1.0
    i=i+1
ENDFOR

uaidname=['3102097','3102104','3102107','3102118','3102124','3102150','3102163','3102164','3102165','3102168','3102193']
n_uaid=N_ELEMENTS(uaidname)
colnum=[33,36,69,33,39,66,8,28,57,49,33]
tick_name=[' ','M13','M12','I4_1','I4_2','I3_1','I3_2','M10','M11','M8','M9',' ']

;*****************************************************************************
;  Read in data.
;*****************************************************************************

FOR uaid=0, n_uaid-1 DO BEGIN
	set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
	set_plot,'ps'
	outfname='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.2.ps'
	device,/landscape,filename=outfname,/color
	!p.multi=[0,2,2]

	infname1='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.dn.sav'
	infname2='/home/jmcintire/VIIRS_Data/FP_13_Data/SMWIR/U'+uaidname[uaid]+'.coeff.reform.sav'
	check=FILE_SEARCH(infname1)
	IF check EQ '' THEN BEGIN
		print,'No file is found.',infname1
		goto,skip_loop
	ENDIF
	print,'Processing file:',infname1
	print,'Processing file:',infname2
	restore,infname1
	restore,infname2

	XF_dn_I_r[*,*,*,*,*]=XF_dn_I_r[*,*,*,*,*]*1000
	XF_L_I_r[*,*,*,*,*]=XF_L_I_r[*,*,*,*,*]*1000
	XF_dn_M_r[*,*,*,*]=XF_dn_M_r[*,*,*,*]*1000
	XF_L_M_r[*,*,*,*]=XF_L_M_r[*,*,*,*]*1000

	XF_dn_I_g[*,*,*,*,*,*,*]=XF_dn_I_g[*,*,*,*,*,*,*]*1000
	XF_L_I_g[*,*,*,*,*,*,*]=XF_L_I_g[*,*,*,*,*,*,*]*1000
	XF_dn_M_g[*,*,*,*,*,*]=XF_dn_M_g[*,*,*,*,*,*]*1000
	XF_L_M_g[*,*,*,*,*,*]=XF_L_M_g[*,*,*,*,*,*]*1000

	IF uaid NE 2 AND uaid NE 5 THEN ndet=ndet_M
	IF uaid EQ 2 OR uaid EQ 5 THEN ndet=ndet_I

	flag=0
	IF uaid EQ 8 OR uaid EQ 9 THEN flag=1

	FOR det_lit=0, ndet-1 DO BEGIN

		bandindex_1=findgen(10)+1
		bandindex_2=WHERE(bandindex_1)+3

		; Plot XF_dn per detector.

		ymax=2
		ymin_1=min(XF_dn_I_r[det_lit,0,*,*,*])
		ymin_2=min(XF_dn_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_dn_I_r[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_dn*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		FOR ib=0, 1 DO BEGIN
			IF flag EQ 0 THEN BEGIN
				oplot,ibdet2[*],XF_dn_I_r[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib], $
					psym=symbol[2*ib],thick=3
				oplot,ibdet2[*],XF_dn_I_r[det_lit,0,ib,*,0],color=lcol[2*ib],thick=3
				oplot,ibdet2[*],XF_dn_I_r[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1], $
					psym=symbol[2*ib+1],thick=3
				oplot,ibdet2[*],XF_dn_I_r[det_lit,0,ib,*,1],color=lcol[2*ib+1],thick=3
			ENDIF
;			IF flag EQ 1 THEN BEGIN
;				oplot,ibdet2[*],XF_dn_I_g[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib], $
;					psym=symbol[2*ib],thick=3
;				oplot,ibdet2[*],XF_dn_I_g[det_lit,0,ib,*,0],color=lcol[2*ib],thick=3
;				oplot,ibdet2[*],XF_dn_I_g[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1], $
;					psym=symbol[2*ib+1],thick=3
;				oplot,ibdet2[*],XF_dn_I_g[det_lit,0,ib,*,1],color=lcol[2*ib+1],thick=3
;			ENDIF
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			IF flag EQ 0 THEN BEGIN
				oplot,det_M[0:15]+1,XF_dn_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4], $
					psym=symbol[ib+4],thick=3
				oplot,det_M[0:15]+1,XF_dn_M_r[det_lit,0,ib,0:15],color=lcol[ib+4],thick=3
			ENDIF
;			IF flag EQ 1 THEN BEGIN
;				oplot,det_M[0:15]+1,XF_dn_M_g[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4], $
;					psym=symbol[ib+4],thick=3
;				oplot,det_M[0:15]+1,XF_dn_M_g[det_lit,0,ib,0:15],color=lcol[ib+4],thick=3
;			ENDIF
		ENDFOR

		; Plot XF_L per detector.

		ymax=2
		ymin_1=min(XF_L_I_r[det_lit,0,*,*,*])
		ymin_2=min(XF_L_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],XF_L_I_r[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='XF_L*1000', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],XF_L_I_r[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib],thick=3
			oplot,ibdet2[*],XF_L_I_r[det_lit,0,ib,*,0],color=lcol[2*ib],thick=3
			oplot,ibdet2[*],XF_L_I_r[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1],thick=3
			oplot,ibdet2[*],XF_L_I_r[det_lit,0,ib,*,1],color=lcol[2*ib+1],thick=3
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			oplot,det_M[0:15]+1,XF_L_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4],thick=3
			oplot,det_M[0:15]+1,XF_L_M_r[det_lit,0,ib,0:15],color=lcol[ib+4],thick=3
		ENDFOR

		; Plot CNR per detector.

		ymax=2
		ymin_1=min(CNR_I_r[det_lit,0,*,*,*])
		ymin_2=min(CNR_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],CNR_I_r[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='CNR', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],CNR_I_r[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib],thick=3
			oplot,ibdet2[*],CNR_I_r[det_lit,0,ib,*,0],color=lcol[2*ib],thick=3
			oplot,ibdet2[*],CNR_I_r[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1],thick=3
			oplot,ibdet2[*],CNR_I_r[det_lit,0,ib,*,1],color=lcol[2*ib+1],thick=3
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			oplot,det_M[0:15]+1,CNR_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4],thick=3
			oplot,det_M[0:15]+1,CNR_M_r[det_lit,0,ib,0:15],color=lcol[ib+4],thick=3
		ENDFOR

		; Plot PVP per detector.

		ymax=2
		ymin_1=min(PVP_I_r[det_lit,0,*,*,*])
		ymin_2=min(PVP_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,ibdet2[*],PVP_I_r[det_lit,0,0,*,0],xrange=[0,ndet_M+1],yrange=[ymin,ymax],ytit='PVP', $
			xtit='detector',charsize=1.2,charthick=5,/nodata
		FOR ib=0, 1 DO BEGIN
			oplot,ibdet2[*],PVP_I_r[det_lit,0,ib,*,0],symsize=1,color=lcol[2*ib],psym=symbol[2*ib],thick=3
			oplot,ibdet2[*],PVP_I_r[det_lit,0,ib,*,0],color=lcol[2*ib],thick=3
			oplot,ibdet2[*],PVP_I_r[det_lit,0,ib,*,1],symsize=1,color=lcol[2*ib+1],psym=symbol[2*ib+1],thick=3
			oplot,ibdet2[*],PVP_I_r[det_lit,0,ib,*,1],color=lcol[2*ib+1],thick=3
		ENDFOR
		FOR ib=0, 5 DO BEGIN
			oplot,det_M[0:15]+1,PVP_M_r[det_lit,0,ib,0:15],symsize=1,color=lcol[ib+4],psym=symbol[ib+4],thick=3
			oplot,det_M[0:15]+1,PVP_M_r[det_lit,0,ib,0:15],color=lcol[ib+4],thick=3
		ENDFOR

		IF uaid EQ 0 THEN band=name_band_2[6]
		IF uaid EQ 1 THEN band=name_band_2[2]
		IF uaid EQ 2 THEN band=name_band_2[0]
		IF uaid EQ 3 THEN band=name_band_2[7]
		IF uaid EQ 4 THEN band=name_band_2[4]
		IF uaid EQ 5 THEN band=name_band_2[1]
		IF uaid EQ 6 THEN band=name_band_2[5]
		IF uaid EQ 7 THEN band=name_band_2[5]
		IF uaid EQ 8 THEN band=name_band_2[5]
		IF uaid EQ 9 THEN band=name_band_2[5]
		IF uaid EQ 10 THEN band=name_band_2[3]

		title='U'+uaidname[uaid]+': Sender Band '+strtrim(band,2)+', Detecter '+ $
			strtrim(string(fix(det_lit+1)),2)
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6     
		set_legend,1,band_name,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0

		; Plot XF_dn per band.

		ymax=2
		ymin_1=min(XF_dn_I_r[det_lit,0,*,*,*])
		ymin_2=min(XF_dn_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='XF_dn*1000',/nodata,XTICKS=11, $
			XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex_1,[XF_dn_M_r[det_lit,0,3,idet],XF_dn_M_r[det_lit,0,2,idet], $
					XF_dn_I_r[det_lit,0,1,idet,0],XF_dn_I_r[det_lit,0,1,idet,1], $
					XF_dn_I_r[det_lit,0,0,idet,0],XF_dn_I_r[det_lit,0,0,idet,1], $
					XF_dn_M_r[det_lit,0,0,idet],XF_dn_M_r[det_lit,0,1,idet], $
					XF_dn_M_r[det_lit,0,4,idet],XF_dn_M_r[det_lit,0,5,idet]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_dn_M_r[det_lit,0,3,idet],XF_dn_M_r[det_lit,0,2,idet], $
					XF_dn_I_r[det_lit,0,1,idet,0],XF_dn_I_r[det_lit,0,1,idet,1], $
					XF_dn_I_r[det_lit,0,0,idet,0],XF_dn_I_r[det_lit,0,0,idet,1], $
					XF_dn_M_r[det_lit,0,0,idet],XF_dn_M_r[det_lit,0,1,idet], $
					XF_dn_M_r[det_lit,0,4,idet],XF_dn_M_r[det_lit,0,5,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_2,[XF_dn_I_r[det_lit,0,1,idet,0],XF_dn_I_r[det_lit,0,1,idet,1], $
					XF_dn_I_r[det_lit,0,0,idet,0],XF_dn_I_r[det_lit,0,0,idet,1]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_2,[XF_dn_I_r[det_lit,0,1,idet,0],XF_dn_I_r[det_lit,0,1,idet,1], $
					XF_dn_I_r[det_lit,0,0,idet,0],XF_dn_I_r[det_lit,0,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot XF_L per band.

		ymax=2
		ymin_1=min(XF_L_I_r[det_lit,0,*,*,*])
		ymin_2=min(XF_L_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='XF_L*1000',/nodata,XTICKS=11, $
			XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex_1,[XF_L_M_r[det_lit,0,3,idet],XF_L_M_r[det_lit,0,2,idet], $
					XF_L_I_r[det_lit,0,1,idet,0],XF_L_I_r[det_lit,0,1,idet,1], $
					XF_L_I_r[det_lit,0,0,idet,0],XF_L_I_r[det_lit,0,0,idet,1], $
					XF_L_M_r[det_lit,0,0,idet],XF_L_M_r[det_lit,0,1,idet], $
					XF_L_M_r[det_lit,0,4,idet],XF_L_M_r[det_lit,0,5,idet]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[XF_L_M_r[det_lit,0,3,idet],XF_L_M_r[det_lit,0,2,idet], $
					XF_L_I_r[det_lit,0,1,idet,0],XF_L_I_r[det_lit,0,1,idet,1], $
					XF_L_I_r[det_lit,0,0,idet,0],XF_L_I_r[det_lit,0,0,idet,1], $
					XF_L_M_r[det_lit,0,0,idet],XF_L_M_r[det_lit,0,1,idet], $
					XF_L_M_r[det_lit,0,4,idet],XF_L_M_r[det_lit,0,5,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_2,[XF_L_I_r[det_lit,0,1,idet,0],XF_L_I_r[det_lit,0,1,idet,1], $
					XF_L_I_r[det_lit,0,0,idet,0],XF_L_I_r[det_lit,0,0,idet,1]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_2,[XF_L_I_r[det_lit,0,1,idet,0],XF_L_I_r[det_lit,0,1,idet,1], $
					XF_L_I_r[det_lit,0,0,idet,0],XF_L_I_r[det_lit,0,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot CNR per band.

		ymax=2
		ymin_1=min(CNR_I_r[det_lit,0,*,*,*])
		ymin_2=min(CNR_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='CNR',/nodata,XTICKS=11,XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex_1,[CNR_M_r[det_lit,0,3,idet],CNR_M_r[det_lit,0,2,idet], $
					CNR_I_r[det_lit,0,1,idet,0],CNR_I_r[det_lit,0,1,idet,1], $
					CNR_I_r[det_lit,0,0,idet,0],CNR_I_r[det_lit,0,0,idet,1], $
					CNR_M_r[det_lit,0,0,idet],CNR_M_r[det_lit,0,1,idet], $
					CNR_M_r[det_lit,0,4,idet],CNR_M_r[det_lit,0,5,idet]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[CNR_M_r[det_lit,0,3,idet],CNR_M_r[det_lit,0,2,idet], $
					CNR_I_r[det_lit,0,1,idet,0],CNR_I_r[det_lit,0,1,idet,1], $
					CNR_I_r[det_lit,0,0,idet,0],CNR_I_r[det_lit,0,0,idet,1], $
					CNR_M_r[det_lit,0,0,idet],CNR_M_r[det_lit,0,1,idet], $
					CNR_M_r[det_lit,0,4,idet],CNR_M_r[det_lit,0,5,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_2,[CNR_I_r[det_lit,0,1,idet,0],CNR_I_r[det_lit,0,1,idet,1], $
					CNR_I_r[det_lit,0,0,idet,0],CNR_I_r[det_lit,0,0,idet,1]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_2,[CNR_I_r[det_lit,0,1,idet,0],CNR_I_r[det_lit,0,1,idet,1], $
					CNR_I_r[det_lit,0,0,idet,0],CNR_I_r[det_lit,0,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		; Plot PVP per band.

		ymax=2
		ymin_1=min(PVP_I_r[det_lit,0,*,*,*])
		ymin_2=min(PVP_M_r[det_lit,0,*,0:15])
		IF ymin_1 LE ymin_2 THEN ymin=ymin_1
		IF ymin_1 GT ymin_2 THEN ymin=ymin_2

		plot,dn,xrange=[0,11],xstyle=1,yrange=[ymin,ymax],ytit='PVP',/nodata,XTICKS=11,XTICKN=tick_name,charsize=0.9
		FOR iii=1, 10 DO oplot,[iii,iii],[-20,ymax],linestyle=2
		FOR idet=0, ndet_I-1 DO BEGIN
			IF idet LT ndet_M THEN BEGIN
				oplot,bandindex_1,[PVP_M_r[det_lit,0,3,idet],PVP_M_r[det_lit,0,2,idet], $
					PVP_I_r[det_lit,0,1,idet,0],PVP_I_r[det_lit,0,1,idet,1], $
					PVP_I_r[det_lit,0,0,idet,0],PVP_I_r[det_lit,0,0,idet,1], $
					PVP_M_r[det_lit,0,0,idet],PVP_M_r[det_lit,0,1,idet], $
					PVP_M_r[det_lit,0,4,idet],PVP_M_r[det_lit,0,5,idet]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_1,[PVP_M_r[det_lit,0,3,idet],PVP_M_r[det_lit,0,2,idet], $
					PVP_I_r[det_lit,0,1,idet,0],PVP_I_r[det_lit,0,1,idet,1], $
					PVP_I_r[det_lit,0,0,idet,0],PVP_I_r[det_lit,0,0,idet,1], $
					PVP_M_r[det_lit,0,0,idet],PVP_M_r[det_lit,0,1,idet], $
					PVP_M_r[det_lit,0,4,idet],PVP_M_r[det_lit,0,5,idet]],color=lcol[idet]
			ENDIF ELSE BEGIN
				oplot,bandindex_2,[PVP_I_r[det_lit,0,1,idet,0],PVP_I_r[det_lit,0,1,idet,1], $
					PVP_I_r[det_lit,0,0,idet,0],PVP_I_r[det_lit,0,0,idet,1]],symsize=1, $
					color=lcol[idet],psym=symbol[idet]
				oplot,bandindex_2,[PVP_I_r[det_lit,0,1,idet,0],PVP_I_r[det_lit,0,1,idet,1], $
					PVP_I_r[det_lit,0,0,idet,0],PVP_I_r[det_lit,0,0,idet,1]],color=lcol[idet]
			ENDELSE
		ENDFOR

		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6
		set_legend,2,chname,lcol,symbol
		!p.multi=[0,2,2]
		!p.position=0
	
		skip_col:
	ENDFOR 	;col

	skip_loop:
ENDFOR 	;uaid
device,/close

!p.multi=0
!p.position=0

END
